---
title: cli
---

# `marvin.cli`

## Submodules
- [`config`](marvin-cli-config)
- [`dev`](marvin-cli-dev)
- [`main`](marvin-cli-main)
- [`migrations`](marvin-cli-migrations)

---

**Parent Module:** [`marvin`](marvin)
